[flashrom] HP Vectra VL420 SFF

Michael Karcher flashrom at mkarcher.dialup.fu-berlin.de
Wed Dec 23 00:50:09 CET 2009


Am Dienstag, den 22.12.2009, 21:05 +0100 schrieb Mattias Mattsson:
> I'm trying to flash the latest BIOS-version on a HP Vectra VL420 SFF
> but it fails with latest flashrom (r811).
This board needs a board enable. I don't like the PCI ID match, as HP
seems to use subsystem device IDs based on chip device IDs instead of
their products. The match is likely to broad.

Mattias, please try this patch, also, please send the output of
"dmidecode -s baseboard-manufacturer" and "dmidecode -s
baseboard-product-name" to this list, in case we are going to implement
DMI-based device detection. Your machine would be a candidate where it
seems useful.

Regards,
  Michael Karcher


Index: board_enable.c
===================================================================
--- board_enable.c	(Revision 803)
+++ board_enable.c	(Arbeitskopie)
@@ -830,7 +830,9 @@
 }
 
 /**
  * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
  */
 static int intel_ich_gpio22_raise(const char *name)
 {
@@ -1246,6 +1248,7 @@
 	{0x1002, 0x4398, 0x1458, 0x5004,  0x1002, 0x4391, 0x1458, 0xb002, NULL,         NULL,          "GIGABYTE",    "GA-MA78GM-S2H",      it87xx_probe_spi_flash},
 	{0x1002, 0x438d, 0x1458, 0x5001,  0x1002, 0x5956, 0x1002, 0x5956, NULL,         NULL,          "GIGABYTE",    "GA-MA790FX-DQ6",     it87xx_probe_spi_flash},
 	{0x1166, 0x0223, 0x103c, 0x320d,  0x102b, 0x0522, 0x103c, 0x31fa, "hp",         "dl145_g3",    "HP",          "DL145 G3",           board_hp_dl145_g3_enable},
+	{0x8086, 0x1a30, 0x103c, 0x1a30,  0x8086, 0x2443, 0x103c, 0x2440, NULL,         NULL,          "HP",          "VL420 SFF",          intel_ich_gpio22_raise},
 	{0x1166, 0x0205, 0x1014, 0x0347,  0x1002, 0x515E, 0x1014, 0x0325, NULL,         NULL,          "IBM",         "x3455",              board_ibm_x3455},
 	{0x1039, 0x5513, 0x8086, 0xd61f,  0x1039, 0x6330, 0x8086, 0xd61f, NULL,         NULL,          "Intel",       "D201GLY",            wbsio_check_for_spi},
 	{0x1022, 0x7468,      0,      0,       0,      0,      0,      0, "iwill",      "dk8_htx",     "IWILL",       "DK8-HTX",            w83627hf_gpio24_raise_2e},
@@ -830,7 +830,9 @@
 
 /**
- * Suited for ASUS P4B266: socket478 + intel 845D + ICH2.
+ * Suited for:
+ *  - Asus P4B266: socket478 + intel 845D + ICH2.
+ *  - (Asus?) P4B-MX (in HP Vectra VL420 SFF): socket 478 + 845D + ICH2
  */
 static int intel_ich_gpio22_raise(const char *name)






More information about the flashrom mailing list